Changelog

### 1.0.0 (2017-04-07)

  * Initial public release

### 1.0.1 (2017-04-13)

  * Integration with pypi and ReadTheDocs.
  * Installation on Mac and Windows.

### 1.0.2 (2017-04-26)

  * Metadata and badge for Python version.
  * Python 3 compatibility changes, part 1.
  * Installation with Coveralls.

### 1.0.3 (2017-04-26)

  * Bugfix: Import of urlparse corrected, fixes Block.show() .

### 1.1.0 (2017-05-10)

  * jQuery DataTables support.
  * HTML anchors.
  * Bugfix: Width of HTML-body no longer hard-coded.

### 1.1.1 (2017-05-10)

  * Bugfix: Static data including DataTables CSS.

### 1.1.2 (2017-06-2)

  * Bugfix: Image size for Matplotlib figure no longer truncated to whole number.
  * Updated download path for wkhtmltopdf in CI setup.
 
### 1.1.3 (2017-06-6)

  * Bugfix: Expansion of user home directory for show().
  * Bugfix: Flexible definition of default type handling for Block() that allows updating.

### 1.1.4 (2017-06-22)

  * Bugfix: When applying operator on rows or columns (e.g. in totals row), replace nan with zero.
  